==> V2.1.3.tar.gz: fe_python_trial/src/config/index.js <==
import Cookie from 'js-cookie'

const url = location.host
const isDev = process.env.NODE_ENV === 'development' //是否本地
const isHh = url.includes('10.196.131.73') //是否是河海版本
const isPro = url.includes('occupationlab.com') //是否职站生产

let host = location.origin + '/'
let bankPath = `${location.origin}/banksystem` // 银行系统
// 121.37.12.51 | 192.168.31.151
if (isDev) {
  host = 'http://192.168.31.151:9000/'
  // host = 'http://121.37.12.51:9000/'
  bankPath = `http://${location.hostname}:8093`
} else if (isPro) {
  host = 'https://occupationlab.com/'
  bankPath = `https://www.huorantech.cn/banksystem`
}
const systemId = Cookie.get('admin-systemId')
/**
 * python8个系统的id和名称
 * id即systemId，从cookie里取
 */
const pythonList = [
    {
        id: 1,
        name: 'Python程序设计教学系统'
    },
    {
        id: 4,
        name: '经济金融建模实验教学系统'
    },
    {
        id: 5,
        name: 'Python数据可视化实验教学系统'
    },
    {
        id: 6,
        name: '金融随机过程实验教学系统'
    },
    {
        id: 7,
        name: '量化投资策略建模实验教学系统'
    },
    {
        id: 8,
        name: '大数据分析实验教学系统'
    },
    {
        id: 9,
        name: 'Python数据清洗教学实验系统'
    },
    {
        id: 10,
        name: 'Python数据采集（爬虫）教学实验系统'
    }
]
export default {
    /**
     * @description 域名
     */
    host,
    /**
      * @description 是否本地
      */
    isDev,
    /**
      * @description 是否是河海版本
      */
    isHh,
    /**
      * @description 是否是职站生产
      */
    isPro,
    /**
     * @description 系统主题色
     * 如果有多个systemId，则显示系统7的主题色
     */
    defaultSystem: systemId.includes(',') ? 7 : systemId,
    /**
     * python子系统
     **/
    pythonList,
    /**
     * 银行系统
     **/
    bankPath,
    /**
     * @description 长时间未操作，自动退出登录时间
     */
    autoLogoutTime: 3600000
}

==> V2.1.6.tar.gz: fe_python_trial/src/config/index.js <==
import Cookie from 'js-cookie'

const url = location.host
const isDev = process.env.NODE_ENV === 'development' //是否本地
const isHh = url.includes('10.196.131.73') //是否是河海版本
const isPro = url.includes('occupationlab.com') //是否职站生产
const isZxy = url.includes('izhixinyun.com') //是否智信云
let vscodeUrl = 'http://121.37.12.51:8088'
let host = location.origin + '/'
let bankPath = `${location.origin}/banksystem` // 银行系统
// 121.37.12.51 | 192.168.31.151
if (isDev) {
  // host = 'http://192.168.31.152:9000/'
  // host = 'http://192.168.31.53:9000/'
  host = 'http://121.37.12.51:9000/'
  // host = 'https://occupationlab.com/'
  bankPath = `http://${location.hostname}:8093`
} else if (isPro) {
  host = 'https://occupationlab.com/'
  bankPath = `https://www.huorantech.cn/banksystem`
	vscodeUrl = 'https://vscode.occupationlab.com'
} else if (isZxy) {
	vscodeUrl = 'https://vscode.izhixinyun.com'
}
vscodeUrl += `?folder=/home/coder/workspace`
const systemId = Cookie.get('admin-systemId')
export default {
    /**
     * @description 域名
     */
    host,
    /**
      * @description 是否本地
      */
    isDev,
    /**
      * @description 是否是河海版本
      */
    isHh,
    /**
      * @description 是否是职站生产
      */
    isPro,
    /**
      * @description 是否智信云
      */
    isZxy,
    /**
     * @description 系统主题色
     * 如果有多个systemId，则显示系统7的主题色
     */
    defaultSystem: systemId.includes(',') ? 7 : systemId,
    /**
     * 银行系统
     **/
    bankPath,
    /**
     * vscode地址
     **/
    vscodeUrl,
    /**
     * @description 长时间未操作，自动退出登录时间
     */
    autoLogoutTime: 3600000
}
